@@ -16,6 +16,7 @@ from .fileimport import FileImport
 from .automation import Automation, Schedule
 from .programming import Programming
 from .authorization import Authorization
+from .email import Email
 
 from .utils.ut import Utils, Structure, Defaults
 from .timeseries import TimeSeries
@@ -194,6 +195,7 @@ class TechStack():
 
         self.FileImport = FileImport(self)
         self.Authorization = Authorization(self)
+        self.Email = Email(self)
         return
 
     def _getAccessToken(self, tokenUrl: str, user: str, password: str, proxies: dict, timeout: int) -> str:
@@ -226,6 +228,7 @@ class TechStack():
         self.objects = Structure._fullStructureNT(self.structure)
         self.inventory = Structure._inventoryNT(self.structure)
         self.inventoryProperty = Structure._inventoryPropertyNT(self.structure)
+        self.scheme = self.client.introspection
 
         return
 
@@ -1660,15 +1663,3 @@ class TechStack():
         if result == None: return
 
         return result['convertId']
-
-# Some stand alone functions
-
-def encodeBase64(file:str):
-    with open(file) as file:
-        content = file.read()
-        content = base64.b64encode(content.encode('ascii'))
-        return content.decode('UTF8')
-        
-def decodeBase64(content:str):
-    return base64.b64decode(content)
-
