@@ -429,7 +429,7 @@ class FileImport():
         """
 
         ## TIMEZONE
-        timeZone = FileUtils._timeZone(timeZone)
+        timeZone = Utils._timeZone(timeZone)
 
         ## CHECK FILE PATH
         files = FileUtils._checkFilePath(filePath, self.raiseException)
@@ -752,7 +752,7 @@ class FileImport():
         """
 
         ## TIMEZONE
-        timeZone = FileUtils._timeZone(timeZone)
+        timeZone = Utils._timeZone(timeZone)
 
         ## CHECK FILE PATH
         files = FileUtils._checkFilePath(filePath, self.raiseException)
