@@ -197,7 +197,7 @@ class Programming():
         return result
 
     def deployFunction(self, functionId:str, deploymentName:str, envVars:dict=None,
-        memoryLimit:str='250M', cpuLimit:float=0.2):
+        memoryLimit:str='250Mi', cpuLimit:float=0.2):
         """
         Deploys a function to make it executable.
 
