@@ -1,5 +1,5 @@
 import pandas as pd
-import pytz
+from typing import Union
 from gql import Client
 from gql.transport.requests import RequestsHTTPTransport
 from loguru import logger
@@ -33,6 +33,7 @@ class TimeSeries():
         self.defaults = core.defaults
         self.structure = core.structure
         self.scheme = core.scheme
+        self.inventory = core.inventory
         return
 
     def addTimeSeriesItems(
@@ -1136,9 +1137,21 @@ class TimeSeries():
 
         return
 
-    def timeSeriesItems(self, inventoryName:str, references:bool=False, fields:list=None, where:str=None, 
-        orderBy:str=None, asc:bool=True, pageSize:int=5000, 
-        arrayPropertiesToPage:list=None, arrayPageSize:int=50) -> pd.DataFrame:
+    def items(
+        self, 
+        inventoryName:str, 
+        references:bool=False, 
+        fields:list=None,
+        where:Union[list,tuple,str]=None, 
+        orderBy:Union[dict,list,str]=None, 
+        asc:Union[list,str]=True, 
+        pageSize:int=5000, 
+        arrayPageSize:int=50,
+        top:int=100000,
+        validityDate:str=None,
+        allValidityPeriods:bool=False,
+        includeSysProperties:bool=False
+        ) -> pd.DataFrame:
         """
         Returns items of an inventory in a DataFrame.
 
@@ -1152,86 +1165,114 @@ class TimeSeries():
         fields: list | str = None
             A list of all properties to be queried. If None, all properties will be queried.
             For referenced items use a '.' between inventory name and property.
-        where: str = None
-            Use a string to add where criteria like
-            'method eq "average" and location contains "Berlin"'.
-            Referenced items are not supported.
-        orderBy: str = None
-            Select a field to sort by.
-        asc: bool = True
+        where: list | tuple | str = None
+            Define arguments critera like  'city eq "Berlin" and use lists for AND-combinations and
+            tuples for OR-combinations. For references use the format inventory.property as 
+            filter criteria.
+        orderBy: dict | list | str = None
+            Use a dict in the form of {property:'ASC'|'DESC'} or 
+            use a list of properties and the asc-argument for sorting direction
+        asc: list | bool = True
             Determines the sort order of items. If set to False, a descending order 
-            is applied.
+            is applied. Use a list, if more properties are selected in orderBy.
         pageSize: int = 5000
             The page size of items that is used to retrieve a large number of items.
-        arrayPropertiesToPage:list = None
-            Array (list) properties that should be paged. Real paging for array properties is 
-            not yet supported. The properties listed here will just make use of of the arrayPageSize.
         arrayPageSize: int = 50
             The page size of list items that is used to page list items in an inventory item.
+        top: int = None
+            Returns a restricted set of items oriented at the latest entries.
+        includeSysProperties: bool = False
+            If True, all system properties available will be queried. If False, 
+            only 'sys_inventoryItemId' will be queried by default. Despite of that, any system 
+            property can be passed to the fields argument as well.
+        validityDate: str = None
+            If the queried inventory has validity periods enabled, only items will be returned, 
+            which have the given timestamp between sys_validTo and sys_validFrom. Items without
+            validity periods are shown as well.
+        allValidityPeriods: bool = False
+            If True and if the queried inventory has validity periods enabled, all validity 
+            periods will be returned. If False, items with validity dates will not be returned.
+
 
         Example:
         --------
-        >>> items('meterData', references=True)
+        >>> items('appartments', references=True)
+        >>> items(
+                'appartments',
+                fields=['address', 'owner'],
+                where=['city == "Berlin"', 'rooms > 2'],
+                orderBy={'size':'DESC', price:'ASC'}
+                )
         """
 
+        if inventoryName not in self.inventory:
+            Utils._error(self, f"'{inventoryName}' does not exist.")
+            return
+
+        # where
+        try:
+            topLevelWhere, resolvedFilterDict = Utils._handleWhere(self, where, inventoryName)
+        except:
+            return
+
+        validityDate = Utils._argNone('validityDate', validityDate)
+        allValidityPeriods = Utils._argNone('allValidityPeriods', allValidityPeriods)
+        
+
+        # core
         deleteId = False
+        propertyDict = Utils._properties(self.scheme, inventoryName, recursive=True, 
+            sysProperties=includeSysProperties)            
         if fields != None:
             if type(fields) != list:
                 fields = [fields]
             if 'sys_inventoryItemId' not in fields:
                 deleteId = True
                 fields += ['sys_inventoryItemId']
-            _fields = Utils._queryFields(fields, recursive=True)
-        else:
-            properties = Utils._properties(self, inventoryName, recursive=True)
-            properties = Utils._propertyList(properties, recursive=references)
-            
-            _fields = Utils._queryFields(properties, recursive=references)
+            _fields = Utils._queryFields(fields, propertyDict['arrayTypeFields'], arrayPageSize, 
+                filter=resolvedFilterDict, recursive=True)
+        else: 
+            properties = Utils._propertyList(propertyDict['properties'], recursive=references)
+            _fields = UtilsTimeSeries._queryFields(properties, propertyDict['arrayTypeFields'], 
+                arrayPageSize, filter=resolvedFilterDict, recursive=references)
+        logger.debug(f"Fields: {_fields}")
 
         if len(_fields) == 0:
             Utils._error(self, f"Inventory '{inventoryName}' not found.")
             return
 
-        resolvedFilter = ''
-        if where != None: 
-            resolvedFilter = Utils._resolveWhereString(self, where)
-        
-        if orderBy != None:
-            if asc != True:
-                _orderBy = f'order: {{ {orderBy}: DESC }}'
-            else:
-                _orderBy = f'order: {{ {orderBy}: ASC }}'
-        else: _orderBy = ''
-
-        if arrayPropertiesToPage != None:
-            listPagination = 'listPagination: [\n'
-            for arrayProperty in arrayPropertiesToPage:
-                listPagination += f'{{ from: 0, size: {arrayPageSize}, propertyPath: "{arrayProperty}" }}\n'
-            listPagination += ']\n'
-        else:
-            listPagination = ''
+        order = Utils._orderItems(self, orderBy, asc)
+        if order == None: return
 
         result = []
         count = 0
+        stop = False
         lastId = ''
 
         while True:
+
+            # Handling top (premature stop)
+            if top != None:
+                loadedItems = pageSize * count
+                if top - loadedItems <= pageSize:
+                    stop = True
+                    pageSize = top - loadedItems
+
             graphQLString= f''' query getItems {{
                     {inventoryName} (
-                            pageSize: {pageSize} 
-                            {listPagination}
+                            pageSize: {pageSize}
+                            {order}
+                            {allValidityPeriods}
+                            {validityDate}
                             {lastId}
-                            {resolvedFilter}
-                            {_orderBy}
+                            {topLevelWhere}
                             ) {{
                         {_fields}
                     }}
                 }}
                 '''
-            if count == 0:
-                Utils._copyGraphQLString(graphQLString)
 
-            _result = Utils._executeGraphQL(self, graphQLString)   
+            _result = Utils._executeGraphQL(self, graphQLString)     
             
             if _result[inventoryName]:
                 result += _result[inventoryName]
@@ -1242,16 +1283,20 @@ class TimeSeries():
             except: 
                 break
 
+            if stop == True: break
+
         df = pd.json_normalize(result)
-        
+       
         if fields != None: #sorts dataframe according to given fields
             try: # for array field this does not work
                 df = df[fields]
-            except:
-                pass 
-        if deleteId: del df['sys_inventoryItemId']
+            except: pass
+        if deleteId: 
+            try: del df['sys_inventoryItemId']
+            except: pass
+
+        return df
 
-        return df   
 
     def units(self) -> pd.DataFrame:
         """
