@@ -174,9 +174,12 @@ class Utils():
             return
 
     def _timeZone(timeZone):
-        if timeZone=='local': 
-            localTimeZone = get_localzone().zone
-            return str(pytz.timezone(localTimeZone))
+        if timeZone == None or timeZone == 'local': 
+            try:
+                localTimeZone = get_localzone().zone
+                return str(pytz.timezone(localTimeZone))
+            except AttributeError:
+                return str(get_localzone())                
         else:
             return str(pytz.timezone(timeZone))
     
