@@ -26,10 +26,13 @@ class AutProgUtils():
 
 
     def _encodeBase64(file:str):
-        with open(file) as file:
+        with open(file, mode='r', encoding='utf-8') as file:
+            BOM = '\ufeff'
             content = file.read()
-            content = base64.b64encode(content.encode('ascii'))
-            return content.decode('UTF8')
+            if content.startswith(BOM):
+                content = content[1:]
+            content = base64.b64encode(content.encode('utf-8'))
+            return content.decode('utf-8')
 
     def _varsToString(vars:dict, type) -> str:
         """Transforms a dict of function variables to a string. All values will be 
@@ -48,3 +51,10 @@ class AutProgUtils():
 
         return _vars
 
+    def _downloadFunctionFile(path, fileName, content):
+        with open(path+fileName, 'w') as f:
+            f.write(base64.b64decode(content).decode('UTF8'))
+
+
+
+
