@@ -370,20 +370,6 @@ class FileUtils(UtilsProperty):
 
         return dataType, isArray, nullable, isReference
 
-    def _timeZone(timeZone):
-        if timeZone==None: 
-            localTimeZone = get_localzone().zone
-            return str(pytz.timezone(localTimeZone))
-        else:
-            return str(pytz.timezone(timeZone))
-
-    def _timeZoneItems(timeZone):
-        if timeZone==None: 
-            localTimeZone = get_localzone().zone
-            return str(pytz.timezone(localTimeZone))
-        else:
-            return str(pytz.timezone('UTC'))
-
     def _convertTimestamp(timestamp, timeZone, dateTimeFormat, timeDelta):
 
         timestamp = datetime.strptime(timestamp, dateTimeFormat)
