@@ -110,4 +110,51 @@ class UtilsTimeSeries():
             Utils._error(self, msg=f"Unknown displayMode '{displayMode}'. Use 'pivot' or 'rows'.")
             return
 
- 
\ No newline at end of file
+ 
+
+    def _queryFields(fieldList:list, arrayTypeFields:list=None, arrayPageSize:int=None, filter:dict=None, recursive=False) -> str:
+        """
+        Transforms a Python list of fields into graphQL String of fields
+        including fields of referenced inventories        
+        """
+
+        def nestedItem(item):
+            nonlocal fields
+            line = ''
+            for i in range(itemLength - 1):
+                if arrayTypeFields != None and item[i] in arrayTypeFields:
+                    if filter != None and item[i] in filter.keys():
+                        line += f'{item[i]} (pageSize: {arrayPageSize}, where: {filter[item[i]]}) {{ '
+                    else:
+                        line += f'{item[i]} (pageSize: {arrayPageSize}) {{ '
+                else:
+                    line += f'{item[i]} {{ '
+            line += f'{item[-1]} '
+            for _ in range(itemLength - 1):
+                line += '}'
+            line += ' \n'
+            fields += line
+
+        fields = ''
+        splitList = [item.split('.') for item in fieldList]
+        logger.debug(f"intermediate step - splitted list: {splitList}")
+    
+        for item in splitList:
+            if len(item) == 1:
+                if item == ['resolution']:
+                    continue
+                fields += f'{item[0]}  \n'
+                
+            else:
+                itemLength = len(item)
+                if recursive == False:
+                    if item[-1] == '_displayValue':  
+                        nestedItem(item)
+                    if item[-1] == 'sys_inventoryItemId':  
+                        nestedItem(item)
+                else:
+                    nestedItem(item)
+
+        fields += f'resolution {{timeUnit, factor}}  \n'
+        fields += f'_dataPeriod {{from, to}}  \n'
+        return fields
\ No newline at end of file
